<?php

require_once dirname(__FILE__) . '/customsql.php';

/**
 * Forwards_Driver_postfixadmin implements the Forwards_Driver API for SQL
 * servers managed by Postfix Admin (http://postfixadmin.sourceforge.net/).
 *
 * $Horde: forwards/lib/Driver/postfixadmin.php,v 1.2.2.2 2009/12/17 11:11:09 jan Exp $
 *
 * Copyright 2009 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file LICENSE for license information (BSDL). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 *
 * @author  Michael Brennen <michael@fishnet.us>
 * @since   Forwards 3.1.1
 * @package Forwards
 */
class Forwards_Driver_postfixadmin extends Forwards_Driver_customsql {

    /**
     * List of required parameters.
     *
     * @var array
     */
    var $_requiredParams = array('phptype');

    /**
     * Constructor.
     *
     * @param string $user   A user name.
     * @param array $params  Configuration parameters for the backend.
     */
    function Forwards_Driver_postfixadmin($user, $realm, $params)
    {
        $params = array_merge_recursive(
            Horde::getDriverConfig('server', 'sql'),
            array('query_select' => 'SELECT * FROM alias WHERE address=\U',
                  'query_set' => 'INSERT INTO alias (address, goto, domain, created, modified) VALUES (\U, \T, \D, NOW(), NOW())',
                  'query_disable' => 'DELETE FROM alias WHERE address=\U',
                  'hordeauth' => 'full',
                  'column_target' => 'goto'));
        parent::Forwards_Driver_customsql($user, $realm, $params);
    }

    /**
     * Begins forwarding of mail for a user.
     *
     * @param string $password    The password of the user.
     * @param string $target      The email address that mail should be
     *                            forwarded to.
     * @param boolean $keeplocal  Keep a copy of forwarded mail in the local
     *                            mailbox.
     */
    function enableForwarding($password, $target, $keeplocal)
    {
        if ($keeplocal == 'on') {
            // To keep a local copy we must append the user's address to the
            // target.
            $myuser = $this->_buildUsername();
            $target .= ',' . $myuser;
        }
        $keeplocal = 'off';
        parent::enableForwarding($password, $target, $keeplocal);
    }

    /**
     * Checks if user is keeping a local copy of forwarded mail.
     *
     * @param string $password  The password of the user.
     *
     * @return boolean  True if user is keeping a local copy of mail,
     *                  otherwise false.
     */
    function isKeepLocal($password)
    {
        // Get current details.
        $current_details = $this->_getUserDetails($password);
        if ($current_details === false ||
            is_a($current_details, 'PEAR_Error')) {
            return $current_details;
        }

        // See if the user's address is in the target.
        return strpos($goto, $current_details['address']) !== false;
    }

    /**
     * Retrieves current target of mail redirection for a user.
     *
     * @param string $password  The password of the user.
     *
     * @return string  The current forwarding mail address, false if no
     *                 forwarding is set, or PEAR_Error on error.
     */
    function currentTarget($password)
    {
        $current_details = $this->_getUserDetails($password);

        if ($current_details === false ||
            is_a($current_details, 'PEAR_Error')) {
            return $current_details;
        }

        // Strip the user's local address if appended to the target.
        $mylocalappend = ',' . $current_details['address'];
        $pos = strpos($current_details['goto'], $mylocalappend); 
        if ($pos > 0 ) {
            return substr($current_details['goto'], 0, $pos);
        }

        return $current_details['goto'];
    }

}
